==> geomview_1.8.1.orig.tar.gz: geomview-1.8.1/src/lib/color/mergein.c <==
/* Copyright (C) 1992-1998 The Geometry Center
 * Copyright (C) 1998-2000 Stuart Levy, Tamara Munzner, Mark Phillips
 *
 * This file is part of Geomview.
 * 
 * Geomview is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * Geomview is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with Geomview; see the file COPYING.  If not, write
 * to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139,
 * USA, or visit http://www.gnu.org.
 */

#if defined(HAVE_CONFIG_H) && !defined(CONFIG_H_INCLUDED)
#include "config.h"
#endif

static char copyright[] = "Copyright (C) 1992-1998 The Geometry Center\n\
Copyright (C) 1998-2000 Stuart Levy, Tamara Munzner, Mark Phillips";


/* Authors: Charlie Gunn, Stuart Levy, Tamara Munzner, Mark Phillips */

#include "color.h"

void
MergeIn( ColorA *f, ColorA *b,ColorA * t )
{
    register float a = b->a;

    t->r = a * f->r;
    t->g = a * f->g;
    t->b = a * f->b;
    t->a = a * f->a;
}

void
MergeInN( ColorA *f,ColorA * b,ColorA * t,int n )
{
    register float a;
    
    while( n-- ) {
        a = b->a;
	t->r = a * f->r;
	t->g = a * f->g;
	t->b = a * f->b;
	t->a = a * f->a;
	f++;
	b++;
	t++;
    }
}

==> geomview_1.9.4.orig.tar.gz: geomview-1.9.4/src/lib/color/mergein.c <==
/* Copyright (C) 1992-1998 The Geometry Center
 * Copyright (C) 1998-2000 Stuart Levy, Tamara Munzner, Mark Phillips
 *
 * This file is part of Geomview.
 * 
 * Geomview is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * Geomview is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with Geomview; see the file COPYING.  If not, write
 * to the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139,
 * USA, or visit http://www.gnu.org.
 */

#if HAVE_CONFIG_H
# include "config.h"
#endif

#if 0
static char copyright[] = "Copyright (C) 1992-1998 The Geometry Center\n\
Copyright (C) 1998-2000 Stuart Levy, Tamara Munzner, Mark Phillips";
#endif


/* Authors: Charlie Gunn, Stuart Levy, Tamara Munzner, Mark Phillips */

#include "color.h"

void
MergeIn( ColorA *f, ColorA *b,ColorA * t )
{
    float a = b->a;

    t->r = a * f->r;
    t->g = a * f->g;
    t->b = a * f->b;
    t->a = a * f->a;
}

void
MergeInN( ColorA *f,ColorA * b,ColorA * t,int n )
{
    float a;
    
    while( n-- ) {
        a = b->a;
	t->r = a * f->r;
	t->g = a * f->g;
	t->b = a * f->b;
	t->a = a * f->a;
	f++;
	b++;
	t++;
    }
}
